@@ -1,7 +1,7 @@
 var _instancing =
 [
     [ "Static Geometry", "_instancing.html#Static-Geometry", null ],
-    [ "Instance Manager", "_instancing.html#Instance-Manager", null ],
+    [ "Explicit Instance Manager", "_instancing.html#Instance-Manager", null ],
     [ "Static Geometry vs Instancing", "_instancing.html#Static-Geometry-vs-Instancing", null ],
     [ "Instancing User-Guide", "_what_is_instancing.html", [
       [ "Instances per batch", "_what_is_instancing.html#InstancesPerBatch", null ],
