@@ -1,5 +1,18 @@
 var NAVTREEINDEX12 =
 {
+"class_ogre_1_1_default_debug_drawer.html":[7,0,0,97],
+"class_ogre_1_1_default_debug_drawer.html#a17230e3fe665e2e810843e340ba4e06b":[6,0,1,97,8],
+"class_ogre_1_1_default_debug_drawer.html#a17230e3fe665e2e810843e340ba4e06b":[7,0,0,97,8],
+"class_ogre_1_1_default_debug_drawer.html#a284fbdec1a311bb00f0074750dda5d6c":[6,0,1,97,6],
+"class_ogre_1_1_default_debug_drawer.html#a284fbdec1a311bb00f0074750dda5d6c":[7,0,0,97,6],
+"class_ogre_1_1_default_debug_drawer.html#a5a40b6836258edf02bd4d4be5b11c09c":[6,0,1,97,7],
+"class_ogre_1_1_default_debug_drawer.html#a5a40b6836258edf02bd4d4be5b11c09c":[7,0,0,97,7],
+"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908":[6,0,1,97,0],
+"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908":[7,0,0,97,0],
+"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908a8db337e1eb78cd6bfc5a8df84ff94b19":[6,0,1,97,0,1],
+"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908a8db337e1eb78cd6bfc5a8df84ff94b19":[7,0,0,97,0,1],
+"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908ab9d8292120ac28cd04f77cd276afa634":[6,0,1,97,0,0],
+"class_ogre_1_1_default_debug_drawer.html#a71da6aec84c0daa8617d642236e91908ab9d8292120ac28cd04f77cd276afa634":[7,0,0,97,0,0],
 "class_ogre_1_1_default_debug_drawer.html#a96bec68667abef108812e67af9992a47":[6,0,1,97,4],
 "class_ogre_1_1_default_debug_drawer.html#a96bec68667abef108812e67af9992a47":[7,0,0,97,4],
 "class_ogre_1_1_default_debug_drawer.html#abd9aa227f93cc19a3203e442343ebe37":[6,0,1,97,5],
@@ -236,18 +249,5 @@ var NAVTREEINDEX12 =
 "class_ogre_1_1_distance_lod_box_strategy.html#a3a10186da1f694019bd56738d523f990":[5,0,4,1,1],
 "class_ogre_1_1_distance_lod_box_strategy.html#a7de1d4d48cc9cef13375bebf3bf5d91b":[5,0,4,1,3],
 "class_ogre_1_1_distance_lod_box_strategy.html#aefc779936e9fe54a627715bbc0a7f3d9":[5,0,4,1,0],
-"class_ogre_1_1_distance_lod_sphere_strategy.html":[5,0,4,2],
-"class_ogre_1_1_distance_lod_sphere_strategy.html#a1836339ae099ab2dcebc31cfcc4a9475":[5,0,4,2,1],
-"class_ogre_1_1_distance_lod_sphere_strategy.html#a86bd0de82734a68148126e872eb92874":[5,0,4,2,2],
-"class_ogre_1_1_distance_lod_sphere_strategy.html#a99b5ef240e4230111c22e2e131474f3f":[5,0,4,2,0],
-"class_ogre_1_1_distance_lod_sphere_strategy.html#ae478d8c56d2ec46b79af762d32494127":[5,0,4,2,3],
-"class_ogre_1_1_distance_lod_strategy_base.html":[5,0,4,3],
-"class_ogre_1_1_distance_lod_strategy_base.html#a0de7722e986cdcca067bc1773feb6065":[5,0,4,3,10],
-"class_ogre_1_1_distance_lod_strategy_base.html#a15f1fe0235a041c18abd9644dbed5d87":[5,0,4,3,0],
-"class_ogre_1_1_distance_lod_strategy_base.html#a3ef487ffc2e8223fbceea0df0bb98e73":[5,0,4,3,7],
-"class_ogre_1_1_distance_lod_strategy_base.html#a4f8f711a88a7ad7308bfb58e525503ab":[5,0,4,3,8],
-"class_ogre_1_1_distance_lod_strategy_base.html#a5b60368988f8c388b97d6af77b7c08c9":[5,0,4,3,11],
-"class_ogre_1_1_distance_lod_strategy_base.html#a65d9d54235e62d66e1f25355926d7a63":[5,0,4,3,6],
-"class_ogre_1_1_distance_lod_strategy_base.html#a8a2e6192e83057b8973b5247a8ff7abe":[5,0,4,3,1],
-"class_ogre_1_1_distance_lod_strategy_base.html#ab26e68a2e700746489699bc1c70e8e18":[5,0,4,3,3]
+"class_ogre_1_1_distance_lod_sphere_strategy.html":[5,0,4,2]
 };
