@@ -1,5 +1,19 @@
 var NAVTREEINDEX19 =
 {
+"class_ogre_1_1_lod_collapse_cost_profiler.html#ae8a2d2cf140fa05e2132f8d8cfe76d2a":[6,0,1,240,2],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#ae8a2d2cf140fa05e2132f8d8cfe76d2a":[7,0,0,240,2],
+"class_ogre_1_1_lod_collapse_cost_quadric.html":[6,0,1,241],
+"class_ogre_1_1_lod_collapse_cost_quadric.html":[7,0,0,241],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a36e8c2daebc2cb8013716485fc472fe0":[6,0,1,241,0],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a36e8c2daebc2cb8013716485fc472fe0":[7,0,0,241,0],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a5fd759d8f5be1763147fa547cc1c2223":[6,0,1,241,2],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a5fd759d8f5be1763147fa547cc1c2223":[7,0,0,241,2],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a6c5d7dbd0032ba9e5722ce7efa2a520e":[6,0,1,241,1],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a6c5d7dbd0032ba9e5722ce7efa2a520e":[7,0,0,241,1],
+"class_ogre_1_1_lod_collapser.html":[5,1,2,1],
+"class_ogre_1_1_lod_collapser.html#a51d851d50ebcee4f77cff26f500ccce7":[5,1,2,1,0],
+"class_ogre_1_1_lod_collapser.html#a8a3dc7a3ba0d2777dd8656429540e8cd":[5,1,2,1,3],
+"class_ogre_1_1_lod_collapser.html#ab2c58971bcc0ecac574ac377b56f3c30":[5,1,2,1,2],
 "class_ogre_1_1_lod_collapser.html#ad292c42636402fafb2eb193264ca67a4":[5,1,2,1,1],
 "class_ogre_1_1_lod_config_serializer.html":[6,0,1,244],
 "class_ogre_1_1_lod_config_serializer.html":[7,0,0,244],
@@ -235,19 +249,5 @@ var NAVTREEINDEX19 =
 "class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[6,0,1,261,6],
 "class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[7,0,0,261,6],
 "class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[6,0,1,261,3],
-"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[7,0,0,261,3],
-"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[6,0,1,261,1],
-"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[7,0,0,261,1],
-"class_ogre_1_1_material.html":[5,0,5,15],
-"class_ogre_1_1_material.html#a008c264b3fa918677120621d6a112f99":[5,0,5,15,38],
-"class_ogre_1_1_material.html#a00967b56ec980480ba12dc6002462c3b":[5,0,5,15,7],
-"class_ogre_1_1_material.html#a00bfe1380be4c044551121bbd7fb8359":[5,0,5,15,72],
-"class_ogre_1_1_material.html#a02b750ad4a1d2c0aa92cfb7039cd7f95":[5,0,5,15,1],
-"class_ogre_1_1_material.html#a046659fb27e92554d2a3f4c5a49c7579":[5,0,5,15,55],
-"class_ogre_1_1_material.html#a0473d5bf1469491e9e40a434c4817127":[5,0,5,15,70],
-"class_ogre_1_1_material.html#a0f19989747e1db91a501ff94212aebba":[5,0,5,15,64],
-"class_ogre_1_1_material.html#a1158a82d9399448666ea415d5f9a10a9":[5,0,5,15,17],
-"class_ogre_1_1_material.html#a145badc7cadec0958241a47b6037b3e6":[5,0,5,15,56],
-"class_ogre_1_1_material.html#a1f51926064eaa39f9d85393b41bb8870":[5,0,5,15,30],
-"class_ogre_1_1_material.html#a2424a948e95a581d1b7de87ea14e7131":[5,0,5,15,52]
+"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[7,0,0,261,3]
 };
