@@ -1,5 +1,22 @@
 var NAVTREEINDEX44 =
 {
+"class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#a3c10273ba4790cfbd48b93e2627f85c2":[5,1,8,0,1,2],
+"class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#a826a5d2848be329361177f0209c13a67":[5,1,8,0,1,4],
+"class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#ab50e9928256ddbd09462938a7e13e3c8":[5,1,8,0,1,1],
+"class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#ac35a15958d618f6e9cb9b2ca6663e219":[5,1,8,0,1,5],
+"class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#ac70a9dbc1dcfc9c742c08a7714ed7fa3":[5,1,8,0,1,3],
+"class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html#adafa196fd89b566090806bde188bbf33":[5,1,8,0,1,0],
+"class_ogre_1_1_terrain_auto_update_lod.html":[5,1,8,1],
+"class_ogre_1_1_terrain_auto_update_lod.html#a370a1a1fc2cd7ff9af7854fca1f1b11a":[5,1,8,1,1],
+"class_ogre_1_1_terrain_auto_update_lod.html#ac4f8917cf562b6ca232f5354fcfa13b3":[5,1,8,1,2],
+"class_ogre_1_1_terrain_auto_update_lod.html#aceb9152f5d90b3477916a455cb9e453c":[5,1,8,1,0],
+"class_ogre_1_1_terrain_auto_update_lod_by_distance.html":[5,1,8,2],
+"class_ogre_1_1_terrain_auto_update_lod_by_distance.html#a92b1da2b733414d315deca08cf90ed87":[5,1,8,2,1],
+"class_ogre_1_1_terrain_auto_update_lod_by_distance.html#aa3c5f7032acaa7eae8f7c7f558fe316b":[5,1,8,2,0],
+"class_ogre_1_1_terrain_auto_update_lod_factory.html":[5,1,8,3],
+"class_ogre_1_1_terrain_auto_update_lod_factory.html#a25bb17eed297bd5986ace6f2836e86df":[5,1,8,3,0],
+"class_ogre_1_1_terrain_global_options.html":[5,1,8,4],
+"class_ogre_1_1_terrain_global_options.html#a01856a71b813370bc57839da50eb76c8":[5,1,8,4,26],
 "class_ogre_1_1_terrain_global_options.html#a099ad9ade850e0b6d3146989441c52bc":[5,1,8,4,41],
 "class_ogre_1_1_terrain_global_options.html#a0aeba371e3e83537d3269e0da4a476b9":[5,1,8,4,38],
 "class_ogre_1_1_terrain_global_options.html#a0d449a2ed56acd7959eb5fc7d894025c":[5,1,8,4,37],
@@ -232,22 +249,5 @@ var NAVTREEINDEX44 =
 "class_ogre_1_1_terrain_paged_world_section.html#a879013c429ee66c99c133d97b82baac6":[5,1,8,11,4],
 "class_ogre_1_1_terrain_paged_world_section.html#a87e0df4770a3be9ff30ae0cdd1fde041":[5,1,8,11,16],
 "class_ogre_1_1_terrain_paged_world_section.html#a924ee057cdc64958a4fc9a56a5568a3a":[5,1,8,11,18],
-"class_ogre_1_1_terrain_paged_world_section.html#a93820dec8e88161aeaa4f65c5520dcca":[5,1,8,11,17],
-"class_ogre_1_1_terrain_paged_world_section.html#a9d208b0b43ad3838f95f9a3309c8ecba":[5,1,8,11,20],
-"class_ogre_1_1_terrain_paged_world_section.html#ab5d58805495931332246ec7d350db12d":[5,1,8,11,7],
-"class_ogre_1_1_terrain_paged_world_section.html#ac4015e82e2e994378bfd26ce7303df7e":[5,1,8,11,1],
-"class_ogre_1_1_terrain_paged_world_section.html#ad03153a817b969e8444bbd2ee0fce219":[5,1,8,11,13],
-"class_ogre_1_1_terrain_paged_world_section.html#ad1ec44d3c798917114aa713a8281edf2":[5,1,8,11,24],
-"class_ogre_1_1_terrain_paged_world_section.html#ad7ed51ef34902c0e264df859d11e48ec":[5,1,8,11,15],
-"class_ogre_1_1_terrain_paged_world_section.html#afef106bd3ba4aec795178319513c1229":[5,1,8,11,12],
-"class_ogre_1_1_terrain_paged_world_section.html#aff3ffe2df67866bfab9a5f054ab1609e":[5,1,8,11,19],
-"class_ogre_1_1_terrain_paged_world_section_1_1_terrain_definer.html":[5,1,8,11,0],
-"class_ogre_1_1_terrain_paged_world_section_1_1_terrain_definer.html#a5174c19ce0378ea535af62b64f103487":[5,1,8,11,0,1],
-"class_ogre_1_1_terrain_paged_world_section_1_1_terrain_definer.html#a943507b7a89e79094496a3b420931de2":[5,1,8,11,0,0],
-"class_ogre_1_1_terrain_paging.html":[5,1,8,12],
-"class_ogre_1_1_terrain_paging.html#a4458c30d6e445823595616adcffadb92":[5,1,8,12,2],
-"class_ogre_1_1_terrain_paging.html#a9626171913fa5a7a0750d1c7fde899be":[5,1,8,12,0],
-"class_ogre_1_1_terrain_paging.html#abd25fd10f56c13f1adc25946318338a8":[5,1,8,12,1],
-"class_ogre_1_1_terrain_quad_tree_node.html":[5,1,8,13],
-"class_ogre_1_1_terrain_quad_tree_node.html#a00fd0fa40466d2d443c7f65fb6c9c4fd":[5,1,8,13,17]
+"class_ogre_1_1_terrain_paged_world_section.html#a93820dec8e88161aeaa4f65c5520dcca":[5,1,8,11,17]
 };
