@@ -1,55 +1,79 @@
 var NAVTREEINDEX59 =
 {
-"namespace_ogre.html#a9e86748bd90b88b63907d4f39900e577":[6,0,1,835],
+"namespace_ogre.html#a5e0882c3b9f7ca32a795f98cf034e428":[6,0,1,633],
+"namespace_ogre.html#a60635457b0b97495b34737baa4fb3f64":[6,0,1,609],
+"namespace_ogre.html#a6519f6582ca047f2c0ae0bb056bb9134":[6,0,1,612],
+"namespace_ogre.html#a660664a63929ba9f460ae738a3ed59eb":[6,0,1,709],
+"namespace_ogre.html#a6bff13b1479556a24ae1636a6251c26b":[6,0,1,701],
+"namespace_ogre.html#a6d84a8d0d69f1c49ad30637016bccc80":[6,0,1,872],
+"namespace_ogre.html#a6e6e978d04d35e4351576d3f6f3e2364":[6,0,1,610],
+"namespace_ogre.html#a70291a99caf16ec1ce14ce4d03ed4f07":[6,0,1,869],
+"namespace_ogre.html#a70fa907104459ee375cbc6e0f43eeb74":[6,0,1,868],
+"namespace_ogre.html#a72f7c7ed96713df7ed929bc19c8f2f1b":[6,0,1,876],
+"namespace_ogre.html#a739a289a4d5235f5f509a1795f5ffd5b":[6,0,1,631],
+"namespace_ogre.html#a793439fa964ffad99ec9ba1f2e4e9f91":[6,0,1,875],
+"namespace_ogre.html#a7e0bc377ed62eee5daa8987e28b2ce93":[6,0,1,654],
+"namespace_ogre.html#a8542e5da4c0e0bda0d0bf5745329ea88":[6,0,1,625],
+"namespace_ogre.html#a86f62030407fdeffab537ac7e98e6ec3":[6,0,1,648],
+"namespace_ogre.html#a8a2a961b4205aacff9c01e81e08d7781":[6,0,1,635],
+"namespace_ogre.html#a8c3bb322713cd9a6e1efc39690a42236":[6,0,1,699],
+"namespace_ogre.html#a8f2f90fa4c83c075e3fae75456ae5ded":[6,0,1,606],
+"namespace_ogre.html#a9140aec81d4c373ea427d72ca046d845":[6,0,1,641],
+"namespace_ogre.html#a9297e4ba862a7506f0c1a62b26b59a24":[6,0,1,867],
+"namespace_ogre.html#a95928aac7888704fcccc644317834fa3":[6,0,1,656],
+"namespace_ogre.html#a99fb0d12485f50c22c3a63a4e060fcd7":[6,0,1,879],
+"namespace_ogre.html#a9aac4c604e6e064ee7636c80ccfc99ed":[6,0,1,658],
+"namespace_ogre.html#a9c21c25fe94d377e08de68d4502c90fd":[6,0,1,878],
+"namespace_ogre.html#a9e86748bd90b88b63907d4f39900e577":[6,0,1,836],
 "namespace_ogre.html#a9fd71fd7bfbb195319bb4ae3ef81f1c7":[6,0,1,706],
-"namespace_ogre.html#aa1036704b0d91baa078a713932ba4d9a":[6,0,1,834],
+"namespace_ogre.html#aa1036704b0d91baa078a713932ba4d9a":[6,0,1,835],
 "namespace_ogre.html#aa381890787803da43b614dee8d9c8994":[6,0,1,653],
 "namespace_ogre.html#aa3a7b6dfb905e6572d62f0dfa3d4274d":[6,0,1,615],
 "namespace_ogre.html#aa45059cb355996532a0ca37f0be9bc98":[6,0,1,627],
 "namespace_ogre.html#aaaaf710eea1e4365b2db4316b2fe133b":[6,0,1,660],
 "namespace_ogre.html#aab7b2d2585219692cd912d3b497802d5":[6,0,1,657],
 "namespace_ogre.html#aad08c34b6cdc67860f9443039c1df9f4":[6,0,1,649],
-"namespace_ogre.html#aaeea8e914de95954f4ccbc680e633ac4":[6,0,1,870],
+"namespace_ogre.html#aaeea8e914de95954f4ccbc680e633ac4":[6,0,1,871],
 "namespace_ogre.html#aaf6cdc855bf9ae5edbf48a7e7dcb27f8":[6,0,1,662],
-"namespace_ogre.html#ab52515a0023834cf1c46ee1327bdf4ca":[6,0,1,833],
+"namespace_ogre.html#ab52515a0023834cf1c46ee1327bdf4ca":[6,0,1,834],
 "namespace_ogre.html#ab582e30a269416bbbe5bc2a3c4ab8675":[6,0,1,705],
 "namespace_ogre.html#ab68581d765ec12b3eb68b9270c5113f5":[6,0,1,624],
 "namespace_ogre.html#ab6e842a18caf062ed73a5d3badd0dd4c":[6,0,1,618],
 "namespace_ogre.html#ab76650f27b9b671a6ad6ba0e466c65aa":[6,0,1,637],
-"namespace_ogre.html#ab8bbcab42b67b21ae639dd3ef57c2932":[6,0,1,862],
+"namespace_ogre.html#ab8bbcab42b67b21ae639dd3ef57c2932":[6,0,1,863],
 "namespace_ogre.html#abce10692dd9c7b0e2b8033a7476c2358":[6,0,1,623],
-"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7":[6,0,1,776],
-"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a0293a379395df95e09c920bd751ee576":[6,0,1,776,3],
-"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a1650c5d2628916d49a2e5b64f97ff1ee":[6,0,1,776,6],
-"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a1ade1bc7e5999ed63eaf91c1de0db21c":[6,0,1,776,1],
-"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a6aecc8aa7824aab71d8956f91f69854b":[6,0,1,776,2],
-"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a740322a149493f1dfc4ae893b396eeb8":[6,0,1,776,5],
-"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a87fbdc88b80bff5b685005912fc952d1":[6,0,1,776,4],
-"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7ad0d24c88b7b4e8907d7b03ca9e4f87d4":[6,0,1,776,0],
+"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7":[6,0,1,777],
+"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a0293a379395df95e09c920bd751ee576":[6,0,1,777,3],
+"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a1650c5d2628916d49a2e5b64f97ff1ee":[6,0,1,777,6],
+"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a1ade1bc7e5999ed63eaf91c1de0db21c":[6,0,1,777,1],
+"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a6aecc8aa7824aab71d8956f91f69854b":[6,0,1,777,2],
+"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a740322a149493f1dfc4ae893b396eeb8":[6,0,1,777,5],
+"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7a87fbdc88b80bff5b685005912fc952d1":[6,0,1,777,4],
+"namespace_ogre.html#ac036050d60e78ed73d02e95fe79884a7ad0d24c88b7b4e8907d7b03ca9e4f87d4":[6,0,1,777,0],
 "namespace_ogre.html#ac6dc520d867be5f194779cc09f54b64c":[6,0,1,620],
 "namespace_ogre.html#ac94fc4008c1165dea017263fee56b273":[6,0,1,628],
 "namespace_ogre.html#acaa9a8f223043079fdd7aae2f064efc7":[6,0,1,643],
 "namespace_ogre.html#ad301aa15d0d8e93db33c91b813a33dc0":[6,0,1,659],
 "namespace_ogre.html#ad77c78fa5a8b5e62550f970a8905c509":[6,0,1,621],
-"namespace_ogre.html#ada8fa477cd38aab81e40b645c60fdffa":[6,0,1,793],
-"namespace_ogre.html#ada8fa477cd38aab81e40b645c60fdffaa40eb0a9c9147623fc32b802587261311":[6,0,1,793,1],
-"namespace_ogre.html#ada8fa477cd38aab81e40b645c60fdffaa49b1f6d28821c5e03dff7b1334d5a6bd":[6,0,1,793,2],
-"namespace_ogre.html#ada8fa477cd38aab81e40b645c60fdffaa7f9c75eb5146038296367ff593ea088c":[6,0,1,793,0],
+"namespace_ogre.html#ada8fa477cd38aab81e40b645c60fdffa":[6,0,1,794],
+"namespace_ogre.html#ada8fa477cd38aab81e40b645c60fdffaa40eb0a9c9147623fc32b802587261311":[6,0,1,794,1],
+"namespace_ogre.html#ada8fa477cd38aab81e40b645c60fdffaa49b1f6d28821c5e03dff7b1334d5a6bd":[6,0,1,794,2],
+"namespace_ogre.html#ada8fa477cd38aab81e40b645c60fdffaa7f9c75eb5146038296367ff593ea088c":[6,0,1,794,0],
 "namespace_ogre.html#add43c0bf87f4217edbc794d78c3fd421":[6,0,1,702],
-"namespace_ogre.html#ae1989b3ea4f950a490576b517adfa511":[6,0,1,808],
-"namespace_ogre.html#ae1989b3ea4f950a490576b517adfa511a0c1ad48a3656afd4521bc4a62b1d37e4":[6,0,1,808,1],
-"namespace_ogre.html#ae1989b3ea4f950a490576b517adfa511ad1123149031a19f6e3d2fa5be9fb2555":[6,0,1,808,0],
+"namespace_ogre.html#ae1989b3ea4f950a490576b517adfa511":[6,0,1,809],
+"namespace_ogre.html#ae1989b3ea4f950a490576b517adfa511a0c1ad48a3656afd4521bc4a62b1d37e4":[6,0,1,809,1],
+"namespace_ogre.html#ae1989b3ea4f950a490576b517adfa511ad1123149031a19f6e3d2fa5be9fb2555":[6,0,1,809,0],
 "namespace_ogre.html#ae22ca152f6804405ac4dfb48ad7b3a8f":[6,0,1,704],
 "namespace_ogre.html#ae2a8e4debf1ea6d6cc2b6795e3174f38":[6,0,1,640],
 "namespace_ogre.html#ae9aa0b56067c2069d99ccc9894cf9a03":[6,0,1,718],
 "namespace_ogre.html#aec93725f3ea0bb47424b11e401550e4a":[6,0,1,664],
 "namespace_ogre.html#aecf82a286f08cdf003677d472d33989b":[6,0,1,630],
 "namespace_ogre.html#aee06b1224b6eb1303888d8241d5c16ec":[6,0,1,629],
-"namespace_ogre.html#af72936eba3027e7cea3475eabeb05630":[6,0,1,832],
+"namespace_ogre.html#af72936eba3027e7cea3475eabeb05630":[6,0,1,833],
 "namespace_ogre.html#af851e71354d841df7138f9877c6f5931":[6,0,1,617],
 "namespace_ogre.html#af8656a2c0ef06642f70c4b3745ee80a2":[6,0,1,646],
 "namespace_ogre.html#af9b3423b7c29049c4cfa637d4a41a28f":[6,0,1,663],
-"namespace_ogre.html#afbd510273476ae6d23a3339542c3c63d":[6,0,1,872],
+"namespace_ogre.html#afbd510273476ae6d23a3339542c3c63d":[6,0,1,873],
 "namespace_ogre.html#aff0eec6634048fd4d65b785264243e6c":[6,0,1,661],
 "namespace_ogre_1_1_bullet.html":[6,0,1,0],
 "namespace_ogre_1_1_r_t_shader.html":[6,0,1,1],
@@ -62,8 +86,8 @@ var NAVTREEINDEX59 =
 "namespace_ogre_1_1_r_t_shader.html#ab0694782a83ac342574ac3cf1e053355af47ac7ffe0e82bd495a51205c2132aa4":[6,0,1,1,58,2],
 "namespace_ogre_1_1_volume.html":[6,0,1,2],
 "namespace_ogre_bites.html":[6,0,2],
-"namespace_ogre_bites.html#a99e444799b0151327c5eba14ee48f806":[6,0,2,44],
-"namespace_ogre_bites.html#af9f017cd1b7c2ca7b8f94a8b10f6a5d0":[6,0,2,36],
+"namespace_ogre_bites.html#a99e444799b0151327c5eba14ee48f806":[6,0,2,45],
+"namespace_ogre_bites.html#af9f017cd1b7c2ca7b8f94a8b10f6a5d0":[6,0,2,37],
 "namespace_python.html":[6,0,4],
 "namespace_python_1_1_high_py.html":[6,0,4,0],
 "namespace_python_1_1_numpy.html":[6,0,4,1],
@@ -148,11 +172,11 @@ var NAVTREEINDEX59 =
 "namespacestd.html#af60633ec58754c4b3cc2c56314bf1882":[6,0,5,1],
 "pages.html":[],
 "profiler.html":[2,11],
-"profiler.html#autotoc_md302":[2,11,1,0],
-"profiler.html#autotoc_md303":[2,11,1,1],
-"profiler.html#autotoc_md304":[2,11,1,2],
-"profiler.html#autotoc_md305":[2,11,1,3],
-"profiler.html#autotoc_md306":[2,11,1,4],
+"profiler.html#autotoc_md304":[2,11,1,0],
+"profiler.html#autotoc_md305":[2,11,1,1],
+"profiler.html#autotoc_md306":[2,11,1,2],
+"profiler.html#autotoc_md307":[2,11,1,3],
+"profiler.html#autotoc_md308":[2,11,1,4],
 "profiler.html#profAccuracy":[2,11,2],
 "profiler.html#profFeatures":[2,11,1],
 "profiler.html#profRead":[2,11,0],
@@ -161,21 +185,22 @@ var NAVTREEINDEX59 =
 "reversed-depth.html":[2,12],
 "rtss.html":[1,4],
 "rtss.html#RTSS-Props-API":[1,4,2],
-"rtss.html#autotoc_md244":[1,4,0,0],
-"rtss.html#autotoc_md245":[1,4,0,1],
-"rtss.html#autotoc_md246":[1,4,0,2],
-"rtss.html#autotoc_md247":[1,4,0,3],
-"rtss.html#autotoc_md248":[1,4,0,4],
-"rtss.html#autotoc_md249":[1,4,0,5],
-"rtss.html#autotoc_md250":[1,4,0,6],
-"rtss.html#autotoc_md251":[1,4,0,7],
-"rtss.html#autotoc_md252":[1,4,0,8],
-"rtss.html#autotoc_md253":[1,4,0,9],
-"rtss.html#autotoc_md254":[1,4,0,11],
-"rtss.html#autotoc_md255":[1,4,1,1],
-"rtss.html#autotoc_md256":[1,4,1,2],
-"rtss.html#autotoc_md257":[1,4,3,1],
-"rtss.html#autotoc_md258":[1,4,4,1],
+"rtss.html#autotoc_md245":[1,4,0,0],
+"rtss.html#autotoc_md246":[1,4,0,1],
+"rtss.html#autotoc_md247":[1,4,0,2],
+"rtss.html#autotoc_md248":[1,4,0,3],
+"rtss.html#autotoc_md249":[1,4,0,4],
+"rtss.html#autotoc_md250":[1,4,0,5],
+"rtss.html#autotoc_md251":[1,4,0,6],
+"rtss.html#autotoc_md252":[1,4,0,7],
+"rtss.html#autotoc_md253":[1,4,0,8],
+"rtss.html#autotoc_md254":[1,4,0,9],
+"rtss.html#autotoc_md255":[1,4,0,10],
+"rtss.html#autotoc_md256":[1,4,0,12],
+"rtss.html#autotoc_md257":[1,4,1,1],
+"rtss.html#autotoc_md258":[1,4,1,2],
+"rtss.html#autotoc_md259":[1,4,3,1],
+"rtss.html#autotoc_md260":[1,4,4,1],
 "rtss.html#core-feats":[1,4,3,0],
 "rtss.html#creating-extensions":[1,4,4,5],
 "rtss.html#debugging":[1,4,4,6],
@@ -188,12 +213,12 @@ var NAVTREEINDEX59 =
 "rtss.html#rtss_indepth":[1,4,4],
 "rtss.html#rtss_overview":[1,4,3],
 "rtss.html#rtss_tu_props":[1,4,1],
-"rtss.html#shadow_mapping":[1,4,0,10],
+"rtss.html#shadow_mapping":[1,4,0,11],
 "setup.html":[2,1],
-"setup.html#autotoc_md307":[2,1,2,0],
-"setup.html#autotoc_md308":[2,1,2,0,0],
-"setup.html#autotoc_md309":[2,1,2,0,1],
-"setup.html#autotoc_md310":[2,1,2,0,2],
+"setup.html#autotoc_md309":[2,1,2,0],
+"setup.html#autotoc_md310":[2,1,2,0,0],
+"setup.html#autotoc_md311":[2,1,2,0,1],
+"setup.html#autotoc_md312":[2,1,2,0,2],
 "setup.html#cmake":[2,1,0],
 "setup.html#setupRunning":[2,1,2],
 "setup.html#skeleton":[2,1,1],
@@ -224,30 +249,5 @@ var NAVTREEINDEX59 =
 "struct_ogre_1_1_box.html#a5e545a9bd1bc4151a113267c6529d84f":[5,0,2,3,15],
 "struct_ogre_1_1_box.html#a7c317f774697dbd65dd77e49a0448d2d":[5,0,2,3,12],
 "struct_ogre_1_1_box.html#a7d1b60afde0486382a209908eae208f4":[5,0,2,3,2],
-"struct_ogre_1_1_box.html#a7d29d3b112980c25bd0250dc41cf6ed2":[5,0,2,3,5],
-"struct_ogre_1_1_box.html#a88fa61f841bc444d92075d8b6cb2b43b":[5,0,2,3,11],
-"struct_ogre_1_1_box.html#aaae3f6efb19b7607eef11e8e70fa46a2":[5,0,2,3,0],
-"struct_ogre_1_1_box.html#ac2c94e2d364dfabe7e4406ff8f41ab9e":[5,0,2,3,13],
-"struct_ogre_1_1_box.html#ae46fa4954b4d29f4d051f947fe45c142":[5,0,2,3,14],
-"struct_ogre_1_1_box.html#ae820fd38f7b51e2a907ef601642c898c":[5,0,2,3,8],
-"struct_ogre_1_1_bsp_node_1_1_brush.html":[5,2,1,2,0],
-"struct_ogre_1_1_bsp_node_1_1_brush.html#a1e6740b48713e3cc1fc3bdb62b9a6e64":[5,2,1,2,0,1],
-"struct_ogre_1_1_bsp_node_1_1_brush.html#a62726d014908dee79b47d4048184afaa":[5,2,1,2,0,0],
-"struct_ogre_1_1_bullet_1_1_collision_listener.html":[5,1,1,0],
-"struct_ogre_1_1_bullet_1_1_collision_listener.html#a15ed59bda733b6e63d9f28a58ef38b70":[5,1,1,0,0],
-"struct_ogre_1_1_bullet_1_1_collision_listener.html#a59d545c3645540c9cae1b3b945fd1903":[5,1,1,0,1],
-"struct_ogre_1_1_bullet_1_1_height_field_data.html":[5,1,1,4],
-"struct_ogre_1_1_bullet_1_1_height_field_data.html#a257c833d6d9e346794452786bb52cd2c":[5,1,1,4,0],
-"struct_ogre_1_1_bullet_1_1_height_field_data.html#acd3ff117ec933f22bd5f0f2ddd3e71d7":[5,1,1,4,1],
-"struct_ogre_1_1_bullet_1_1_ray_result_callback.html":[5,1,1,6],
-"struct_ogre_1_1_bullet_1_1_ray_result_callback.html#a0f521584d3810e3339d886f6c26cae83":[5,1,1,6,1],
-"struct_ogre_1_1_bullet_1_1_ray_result_callback.html#a59e08ca9b439889c9d103d8bdc3e96c8":[5,1,1,6,0],
-"struct_ogre_1_1_colour_blend_state.html":[5,0,5,1],
-"struct_ogre_1_1_colour_blend_state.html#a137130fbfd568631e517597aeebf1c03":[5,0,5,1,11],
-"struct_ogre_1_1_colour_blend_state.html#a13e2c27dc6e21b80f1889d3b99682b16":[5,0,5,1,2],
-"struct_ogre_1_1_colour_blend_state.html#a1a8d5d6033ad996dfadaafdad151e25d":[5,0,5,1,10],
-"struct_ogre_1_1_colour_blend_state.html#a297efc16bd85050690f5de4c992a308b":[5,0,5,1,0],
-"struct_ogre_1_1_colour_blend_state.html#a2a86317b4a9efb0c6b4f3f8fe9ff0fbf":[5,0,5,1,7],
-"struct_ogre_1_1_colour_blend_state.html#a32b83f3be2641efbf6567b7d5aef22be":[5,0,5,1,3],
-"struct_ogre_1_1_colour_blend_state.html#a4c9669f21aa6a880dac5b5380310e6b0":[5,0,5,1,8]
+"struct_ogre_1_1_box.html#a7d29d3b112980c25bd0250dc41cf6ed2":[5,0,2,3,5]
 };
