@@ -6,5 +6,5 @@ var searchData=
   ['windoweventutilities_3',['WindowEventUtilities',['../class_ogre_bites_1_1_window_event_utilities.html',1,'OgreBites']]],
   ['wireboundingbox_4',['WireBoundingBox',['../class_ogre_1_1_wire_bounding_box.html',1,'Ogre']]],
   ['workqueue_5',['WorkQueue',['../class_ogre_1_1_work_queue.html',1,'Ogre']]],
-  ['worldfragment_6',['WorldFragment',['../struct_ogre_1_1_scene_query_1_1_world_fragment.html',1,'Ogre::SceneQuery']]]
+  ['worldfragment_6',['WorldFragment',['../struct_ogre_1_1_world_fragment.html',1,'Ogre']]]
 ];
